Index: branches/network/src/Makefile.am
===================================================================
--- branches/network/src/Makefile.am	(revision 6362)
+++ branches/network/src/Makefile.am	(revision 6363)
@@ -100,5 +100,4 @@
                  story_entities/single_player_world.h \
                  story_entities/multi_player_world.h \
-                 story_entities/network_world.h \
                  world_entities/world_entity.h \
                  world_entities/camera.h \
Index: branches/network/src/story_entities/game_world.h
===================================================================
--- branches/network/src/story_entities/game_world.h	(revision 6362)
+++ branches/network/src/story_entities/game_world.h	(revision 6363)
@@ -79,6 +79,4 @@
     virtual void display ();
 
-    virtual void debug ();
-
 
   protected:
Index: branches/network/src/story_entities/multi_player_world.cc
===================================================================
--- branches/network/src/story_entities/multi_player_world.cc	(revision 6362)
+++ branches/network/src/story_entities/multi_player_world.cc	(revision 6363)
@@ -32,4 +32,5 @@
 
 MultiPlayerWorld::MultiPlayerWorld(const TiXmlElement* root)
+  : GameWorld(root)
 {
   this->constuctorInit("", -1);
@@ -86,5 +87,5 @@
 void MultiPlayerWorld::loadParams(const TiXmlElement* root)
 {
-  static_cast<GameWorld*>(this)->loadParams(root);
+  static_cast<MultiPlayerWorld*>(this)->loadParams(root);
 
   PRINTF(4)("Creating a MultiPlayerWorld\n");
@@ -99,7 +100,7 @@
  * before the load and after the proceeding storyentity has finished
  */
-ErrorMessage GameWorld::preLoad()
+ErrorMessage MultiPlayerWorld::preLoad()
 {
-  static_cast<GameWorld*>(this)->preLoad();
+  static_cast<MultiPlayerWorld*>(this)->preLoad();
 
   /* the the single player specific stuff */
@@ -108,9 +109,9 @@
 
 /**
  *  loads the GameWorld by initializing all resources, and set their default values.
  */
-ErrorMessage GameWorld::load()
+ErrorMessage MultiPlayerWorld::load()
 {
-  static_cast<GameWorld*>(this)->load();
+  static_cast<MultiPlayerWorld*>(this)->load();
 
   /* the the single player specific stuff here */
@@ -119,9 +120,9 @@
 
 /**
  *  post loads the GameWorld by initializing all resources, and set their default values.
  */
-ErrorMessage GameWorld::postLoad()
+ErrorMessage MultiPlayerWorld::postLoad()
 {
-  static_cast<GameWorld*>(this)->postLoad();
+  static_cast<MultiPlayerWorld*>(this)->postLoad();
 
   /* the single player specific stuff here */
@@ -108,9 +109,9 @@
 
 /**
- *  loads the GameWorld by initializing all resources, and set their default values.
+ *  loads the MultiPlayerWorld by initializing all resources, and set their default values.
  */
@@ -119,9 +120,9 @@
 
 /**
- *  post loads the GameWorld by initializing all resources, and set their default values.
+ *  post loads the MultiPlayerWorld by initializing all resources, and set their default values.
  */
Index: branches/network/src/story_entities/single_player_world.cc
===================================================================
--- branches/network/src/story_entities/single_player_world.cc	(revision 6362)
+++ branches/network/src/story_entities/single_player_world.cc	(revision 6363)
@@ -88,5 +88,5 @@
 void SinglePlayerWorld::loadParams(const TiXmlElement* root)
 {
-  static_cast<GameWorld*>(this)->loadParams(root);
+  static_cast<SinglePlayerWorld*>(this)->loadParams(root);
 
   PRINTF(4)("Creating a SinglePlayerWorld\n");
@@ -101,7 +101,7 @@
  * before the load and after the proceeding storyentity has finished
  */
-ErrorMessage GameWorld::preLoad()
+ErrorMessage SinglePlayerWorld::preLoad()
 {
-  static_cast<GameWorld*>(this)->preLoad();
+  static_cast<SinglePlayerWorld*>(this)->preLoad();
 
   /* the the single player specific stuff */
@@ -110,9 +110,9 @@
 
 /**
  *  loads the GameWorld by initializing all resources, and set their default values.
  */
-ErrorMessage GameWorld::load()
+ErrorMessage SinglePlayerWorld::load()
 {
-  static_cast<GameWorld*>(this)->load();
+  static_cast<SinglePlayerWorld*>(this)->load();
 
   /* the the single player specific stuff here */
@@ -132,9 +132,9 @@
 
 /**
  *  post loads the GameWorld by initializing all resources, and set their default values.
  */
-ErrorMessage GameWorld::postLoad()
+ErrorMessage SinglePlayerWorld::postLoad()
 {
-  static_cast<GameWorld*>(this)->postLoad();
+  static_cast<SinglePlayerWorld*>(this)->postLoad();
 
   /* the single player specific stuff here */
@@ -110,9 +110,9 @@
 
 /**
- *  loads the GameWorld by initializing all resources, and set their default values.
+ *  loads the SinglePlayerWorld by initializing all resources, and set their default values.
  */
@@ -132,9 +132,9 @@
 
 /**
- *  post loads the GameWorld by initializing all resources, and set their default values.
+ *  post loads the SinglePlayerWorld by initializing all resources, and set their default values.
  */
